package com.wd.workoffice.retrofit;


import com.wd.workoffice.app.BaseBean;
import com.wd.workoffice.app.Config;
import com.wd.workoffice.bean.ProDetail;

import org.json.JSONObject;

import java.util.Map;

import io.reactivex.Observable;
import okhttp3.RequestBody;
import retrofit2.Call;
import retrofit2.http.Body;
import retrofit2.http.GET;
import retrofit2.http.POST;
import retrofit2.http.PUT;
import retrofit2.http.Path;
import retrofit2.http.Query;
import retrofit2.http.QueryMap;

/**
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public interface ApiService {
//    String DOMAIN = Config.DEBUG ? "http://121.36.41.30:9001/" : "http://zwang.bat100.net.cn:8000/";

    String DOMAIN = Config.DEBUG ? "http://zwang.bat100.net.cn:8000/" : "http://zwang.bat100.net.cn:8000/";


    /**
     * 用户注册
     *
     * @return
     */
    @POST("/open/sys/user/register")
    Observable<BaseBean> register(@Body RequestBody requestBody);

    /**
     * 登录
     * grant_type=userNew
     * grant_type=phone
     *
     * @return
     */
    @POST("/login")
    Call<BaseBean> login(@Query("grant_type") String type, @Body RequestBody requestBody);

    /**
     * 退出登录
     *
     * @return
     */
    @POST("/authorities/logout")
    Observable<BaseBean> logout();

    /**
     * 忘记密码（短信验证码的方式，重置密码）
     *
     * @return
     */
    @PUT("/open/change-pwd-forget")
    Observable<BaseBean> forgetPwd(@Query("phone") String phone,
                                   @Query("verifyCode") String verifyCode, @Query("newPassword") String newPassword);

    /**
     * 激活员工前获取该员工信息
     *
     * @return
     */
    @GET("/open/pre-activation/{phone}")
    Observable<JSONObject> getInfo(@Path("phone") String phone);

    /**
     * 发送短信验证码
     *
     * @param phone
     * @param type: login、register、alterPwd
     * @return
     */
    @GET("/open/sms/ckCode/{phone}")
    Observable<BaseBean> code(@Path("phone") String phone, @Query("type") String type);

    /**
     * 验证验证码
     *
     * @param phone
     * @return
     */
    @GET("/open/verify-sms-code")
    Observable<BaseBean> verifyCode(@Query("phone") String phone,
                                    @Query("verifyCode") String verifyCode, @Query("type") String type);


    /**
     * 激活用户
     *
     * @return
     */
    @POST("/open/activation-user")
    Observable<JSONObject> activation(@QueryMap Map<String, Object> param);

    /**
     * 部门列表
     *
     * @return
     */
    @GET("/open/sys/dept/list")
    Observable<BaseBean> depList();

    /**
     * 根据权限 获取生产厂
     *
     * @return
     */
    @GET("/sub-process/dept-list")
    Observable<BaseBean> getDepByPermission(@Query("permission") String permission);

    /**
     * 根据部门、流程、往来单位获取子流程
     *
     * @param processCode
     * @param transitPartId 往来单位id(客戶id)
     * @return
     */
    @GET("/sub-process/listByDPT")
    Observable<BaseBean> getProcess(@Query("processCode") String processCode, @Query("transitPartId") Integer transitPartId);

    /**
     * 根据往来单位的类别 获取当前用户所维护的往来单位列表
     * <p>
     * name
     * partTypeCode partTypeCode:SUPPLIER-供应商
     * * CUSTOMER-客户
     * * TRANSPORTERS-运输商
     *
     * @return
     */
    @GET("/transitpart/page/list/current-user/part-type")
    Observable<BaseBean> getClient(@QueryMap Map<String, Object> param);

    /**
     * 根据关联往来单位（类别为客户）和生产厂（产品上架部门） --> 获取产品列表
     * <p>
     * outDeptId
     * transitPartId 销售订单（客户id），外采购订单（供应商id）
     * <p>
     * processType 销售流程PROCESS_SALE
     * 外采购流程PROCESS_PURCHAS
     *
     * @return
     */
    @GET("product/page/list/by/outDept/transit-part")
    Observable<BaseBean> getProductList(@QueryMap Map<String, Object> param);

    /**
     * 仓库
     * <p>
     * deptId
     * customerId
     * sign       固定值send
     * 供应   参数是3个
     * 坩埚的话  内部交易一个参数 deptId
     *
     * @return
     */
    @GET("/stock/search-list")
    Observable<BaseBean> getStock(@QueryMap Map<String, Object> param);


    /**
     * 用户信息
     *
     * @return
     */
    @GET("/sys/user/userInfo")
    Observable<BaseBean> userInfo();

    /**
     * 订单
     * <p>
     * orderStatus app端订单筛选：
     * 100：待审核
     * 200：待接单
     * 710： 待生产 （已接单、申请提前结束）
     * 500：已入库
     * 600： 已交付
     * 960：已关闭 （审核失败、已拒单、已提前结束）
     * identity    1:作为买家(销售部门) 2:作为卖家(生产部门)
     *
     * @return
     */
    @GET("/saleOrder/current-user/page/list")
    Observable<BaseBean> getOrder(@QueryMap Map<String, Object> param);

    /**
     * 外采购订单
     * <p>
     * orderStatus app端订单筛选：
     * 100：待审核
     * 200：待接单
     * 300 + 410 = 710： 待生产 （已接单、申请提前结束）
     * 500：已入库
     * 600： 已交付
     * 220 + 320 + 420 = 960 ：已关闭 （审核失败、已拒单、已提前结束）
     * identity    1:作为买家(销售部门) 2:作为卖家(生产部门)
     *
     * @return
     */
    @GET("/purchaseOrder/current-user/page/list")
    Observable<BaseBean> getOutOrder(@QueryMap Map<String, Object> param);

    /**
     * 内部
     * <p>
     * orderStatus app端订单筛选：
     * 100：待审核
     * 200：待接单
     * 300 + 410 = 710： 待生产 （已接单、申请提前结束）
     * 500：已入库
     * 600： 已交付
     * 220 + 320 + 420 = 960 ：已关闭 （审核失败、已拒单、已提前结束）
     * identity    1:作为买家(销售部门) 2:作为卖家(生产部门)
     *
     * @return
     */
    @GET("/insideOrder/current-user/page/list")
    Observable<BaseBean> getInsideOrder(@QueryMap Map<String, Object> param);

    /**
     * 供应订单
     * <p>
     * orderStatus app端订单筛选：
     * 100：待审核
     * 200：待接单
     * 300 + 410 = 710： 待生产 （已接单、申请提前结束）
     * 500：已入库
     * 220 + 320 + 420 = 960 ：已关闭 （审核失败、已拒单、已提前结束）
     * identity    1:作为买家(销售部门) 2:作为卖家(生产部门)
     *
     * @return
     */
    @GET("/supplierOrder/current-user/page/list")
    Observable<BaseBean> getSupplierOrder(@QueryMap Map<String, Object> param);


    /**
     * 产品列表
     * <p>
     * processType
     * ofKind      产品种类SM:自制成品OS:外购贴牌RM:原料
     * statu 冻结标记0冻结1正常
     * isExpectOut  是否上架true:上架false:未上架
     * searchValue 模糊搜索（图号、名称）
     *
     * @return
     */
    @GET("/product/app/page/list")
    Observable<BaseBean> getPro(@QueryMap Map<String, Object> param);

    /**
     * 产品详情
     * transitPartRelList 往来单位关联
     * partTypeCode： SUPPLIER-供应商 CUSTOMER-客户 TRANSPORTERS-运输商
     * name：往来单位名称
     * address：往来单位地址
     * accountName：负责人
     * deptName：负责部门
     * outDeptRelList 上架情况
     * createdTime：上架时间
     * deptName：上架部门
     * outByUserName：上架操作人
     *
     * @return
     */
    @GET("/product/app/detail/{productId}")
    Observable<ProDetail> getProDetail(@Path("productId") Integer id);

    /**
     * 产品详情
     * productId
     * current
     * size
     *
     * @return
     */
    @GET("/product-price-change/page/list")
    Observable<BaseBean> getProHistoryPrice(@QueryMap Map<String, Object> param);

    /**
     * 产品详情
     * internalPrice 价格（内部价格）
     * id
     * remark
     *
     * @return
     */
    @PUT("/product/price")
    Observable<BaseBean> modifyProPrice(@Body RequestBody requestBody);


    /**
     * 上下架
     * shelfAction
     * id
     *
     * @return
     */
    @PUT("/product/app/shelf")
//    Observable<BaseBean> onSalePro(@Body RequestBody requestBody);
    Observable<BaseBean> onSalePro(@QueryMap Map<String, Object> param);

    /**
     * 下单
     * <p>
     * customerId 客户ID
     * launchUserId 下单用户ID
     * launchDeptId	下单部门ID
     * receiveDeptId	接单部门ID
     * launchOrderAmount下单总金额
     * subProcessId	子流程ID
     * expandInfo 第二层:订单扩展信息
     * 备注: 第二层:订单扩展信息
     * <p>
     * orderItems
     *
     * @return
     */
    @POST("saleOrder/start")
    Observable<BaseBean> submitSaleOrder(@Body RequestBody requestBody);

    /**
     * 获取客户分厂
     *
     * @param param
     * @return
     */
    @GET("/customer-branch-factory/page/init")
    Observable<BaseBean> getClientFactory(@QueryMap Map<String, Object> param);

    /**
     * app端往来单位分页列表
     *
     * @param param
     * @return
     */
    @GET("/transitpart/app/page/list")
    Observable<BaseBean> getContacts(@QueryMap Map<String, Object> param);

    /**
     * 部门信息
     *
     * @return
     */
    @GET("/dept-account-balance/app/account-balance-info")
    Observable<BaseBean> getAccount();

    /**
     * 获取部门账户的流水
     *
     * @param param
     * @return
     */
    @GET("/finance/flow/page/list")
    Observable<BaseBean> getFlow(@QueryMap Map<String, Object> param);

    /**
     * 仓库
     *
     * @param param stockTypeId 库存类别id
     *              status 1：启用 0：停用
     *              isShowByDateDesc 是否按时间倒叙展示
     *              siteType IN：厂内库 OUT：场外库
     *              searchKey 按名称模糊搜索时，该参数为name
     *              searchValue 模糊搜索的关键字
     * @return
     */
    @GET("/stock/page/list")
    Observable<BaseBean> getWarehouse(@QueryMap Map<String, Object> param);

    /**
     * 仓库
     *
     * @param param stockTypeId 库存类别id
     *              status 1：启用 0：停用
     *              isShowByDateDesc 是否按时间倒叙展示
     *              siteType IN：厂内库 OUT：场外库
     *              searchKey 按名称模糊搜索时，该参数为name
     *              searchValue 模糊搜索的关键字
     * @return
     */
    @GET("/stockQuantity/app/page/listOfOrder")
    Observable<BaseBean> getWareHouseOrder(@QueryMap Map<String, Object> param);

    /**
     * 获取部门列表（不分页）
     *
     * @param param includeCO  1包含集团和冻结部门 0：不包含集团和冻结部门(int)
     *              includeFreeze   包含冻结部门 0：不包含冻结部门(int)
     *              name
     * @return
     */
    @GET("/sys/dept/list")
    Observable<BaseBean> getDep(@QueryMap Map<String, Object> param);

    /**
     * 获取部门详情
     *
     * @param id
     * @return
     */
    @GET("/sys/dept/{deptId}")
    Observable<BaseBean> getDepDetail(@Path("deptId") String id);

    /**
     * 分页查询仓库类别信息
     *
     * @return
     */
    @GET("/stockType/app/search/list")
    Observable<BaseBean> getStockType(@QueryMap Map<String, Object> param);

    /**
     * 查看往来单位详情
     *
     * @return
     */
    @GET("/transitpart/{id}")
    Observable<BaseBean> contactInfo(@Path("id") String id);

    /**
     * app端从往来单位进入查看收票单
     *
     * @return
     */
    @GET("/receiptInvoiceApply/app/page/list/part")
    Observable<BaseBean> receiveTicket(@QueryMap Map<String, Object> param);

    /**
     * app端从往来单位进入查看开票单
     *
     * @return
     */
    @GET("/invoiceApply/app/page/list/part")
    Observable<BaseBean> openTicket(@QueryMap Map<String, Object> param);

    /**
     * 库存数量：一个仓库里的产品列表
     *
     * @return
     */
    @GET("/stockQuantity/app/page/list")
    Observable<BaseBean> stockList(@QueryMap Map<String, Object> param);
    /**
     * 库存数量明细：一个仓库下一个产品里的订单列表
     *
     * @return
     */
    @GET("/stockQuantityDetail/app/page/list")
    Observable<BaseBean> stockDetail(@QueryMap Map<String, Object> param);

    /**
     * 库存数量流水
     *
     * @return
     */
    @GET("/stockQuantityFlow/page/list")
    Observable<BaseBean> stockFlow(@QueryMap Map<String, Object> param);

    /**
     * 库存数量明细流水
     *
     * @return
     */
    @GET("/stockQuantityDetailFlow/page/list")
    Observable<BaseBean> stockDetailFlow(@QueryMap Map<String, Object> param);

    /**
     * 一个订单的详情[从订单列表进入]
     *
     * @return
     */
    @GET("/stockQuantity/app/oneOfOrder/{orderId}")
    Observable<BaseBean> stockDetailFlow(@Path("orderId")String id , @Path("orderType")String orderType);

    /**
     * 获取当前用户的角色，数据、部门权限列表
     *
     * @return
     */
    @GET("/privilege/detail")
    Observable<BaseBean> permissionDetail();

}
